@@ -8,8 +8,8 @@
 (require 'mew)
 (eval-when-compile
   (cond
-   ((mew-which-el "efs")
-    (require 'efs))
+;;   ((mew-which-el "efs")
+;;    (require 'efs))
    ((mew-which-el "ange-ftp")
     (require 'ange-ftp))))
 
@@ -20,7 +20,7 @@
 
 (defvar mew-ext-default-access-type "anon-ftp")
 
-(defvar mew-ext-ftp-server-list 
+(defvar mew-ext-ftp-server-list
   '("ftp.example.org" "ftp.example.jp"))
 
 (defvar mew-ext-encode-switch
@@ -43,16 +43,16 @@
     ("mail-server" mew-ext-mail-server mew-ext-mail-server-ext)
     ("url"         mew-ext-url         mew-ext-url-ext))) ;; RFC 2017
 
-(defsubst mew-ext-get-func (acc-type)
+(defun mew-ext-get-func (acc-type)
   (nth 1 (mew-assoc-match acc-type mew-ext-switch 0)))
 
-(defsubst mew-ext-get-func-ext (acc-type)
+(defun mew-ext-get-func-ext (acc-type)
   (nth 2 (mew-assoc-match acc-type mew-ext-switch 0)))
 
-(defvar mew-ext-include-switch 
+(defvar mew-ext-include-switch
   '(("local-file" mew-ext-include-local-file)))
 
-(defsubst mew-ext-include-get-func (acc-type)
+(defun mew-ext-include-get-func (acc-type)
   (nth 1 (mew-assoc-case-equal acc-type mew-ext-include-switch 0)))
 
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
@@ -61,28 +61,28 @@
 ;;;
 
 (cond
- ((mew-which-el "efs")
-  (defun mew-ext-file-name-completion (file path)
-    (require 'efs)
-    (let ((efs-tmp-name-template mew-temp-file))
-      (efs-file-name-completion file path)))
-  (defun mew-ext-file-name-all-completions (file path)
-    (require 'efs)
-    (let ((efs-tmp-name-template mew-temp-file))
-      (efs-file-name-all-completions file path)))
-  (defun mew-ext-expand-dir (host user dir)
-    (require 'efs)
-    (let ((efs-tmp-name-template mew-temp-file) exp)
-      (setq exp (efs-expand-file-name (format "/%s@%s:%s" user host dir)))
-      (if (string-match ".*:\\(.*\\)$" exp)
-	  (match-string 1 exp))))
-  (defun mew-ext-copy-file-internal (remote local passwd)
-    (require 'efs)
-    (let ((efs-tmp-name-template mew-temp-file)
-	  (efs-generate-anonymous-password passwd)
-	  (parsed (efs-ftp-path remote)))
-      (efs-copy-file-internal remote parsed local nil 
-			      nil nil nil nil t 'image))))
+;;  ((mew-which-el "efs")
+;;   (defun mew-ext-file-name-completion (file path)
+;;     (require 'efs)
+;;     (let ((efs-tmp-name-template mew-temp-file))
+;;       (efs-file-name-completion file path)))
+;;   (defun mew-ext-file-name-all-completions (file path)
+;;     (require 'efs)
+;;     (let ((efs-tmp-name-template mew-temp-file))
+;;       (efs-file-name-all-completions file path)))
+;;   (defun mew-ext-expand-dir (host user dir)
+;;     (require 'efs)
+;;     (let ((efs-tmp-name-template mew-temp-file) exp)
+;;       (setq exp (efs-expand-file-name (format "/%s@%s:%s" user host dir)))
+;;       (if (string-match ".*:\\(.*\\)$" exp)
+;;	 (match-string 1 exp))))
+;;   (defun mew-ext-copy-file-internal (remote local passwd)
+;;     (require 'efs)
+;;     (let ((efs-tmp-name-template mew-temp-file)
+;;	  (efs-generate-anonymous-password passwd)
+;;	  (parsed (efs-ftp-path remote)))
+;;       (efs-copy-file-internal remote parsed local nil
+;;			      nil nil nil nil t 'image))))
  ((mew-which-el "ange-ftp")
   (defun mew-ext-file-name-completion (file path)
     (require 'ange-ftp)
@@ -119,7 +119,7 @@
 	   (attachdir (mew-attachdir))
 	   file filepath ct)
       ;; attachdir / {subdir/} dir
-      (if (not (string= subdir "")) 
+      (if (not (string= subdir ""))
 	  (setq attachdir (expand-file-name subdir attachdir)))
       ;; attachdir / file
       (setq filepath (mew-random-filename attachdir 1 nil mew-ext-suffix))
@@ -129,7 +129,7 @@
 	(setq ct (mew-ext-encode filepath))
 	(setq mew-encode-syntax
 	      (mew-syntax-insert-entry
-	       mew-encode-syntax 
+	       mew-encode-syntax
 	       nums
 	       (mew-encode-syntax-single file ct)))
 	(mew-encode-syntax-print mew-encode-syntax)))))
@@ -137,7 +137,7 @@
 (defun mew-create-content-id ()
   ;; this is not unique if used with very short interval.
   ;; but it's ok
-  (format "<%s.%s.%s@%s>" (nth 0 (current-time)) (nth 1 (current-time)) 
+  (format "<%s.%s.%s@%s>" (nth 0 (current-time)) (nth 1 (current-time))
 	  (emacs-pid) (system-name)))
 
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
@@ -147,18 +147,18 @@
     (with-temp-buffer
       ;;content-header
       (setq access-type (mew-input-general
-			 "Access type" mew-ext-encode-switch t 
+			 "Access type" mew-ext-encode-switch t
 			 mew-ext-default-access-type))
       (setq ret (funcall (cdr (assoc access-type mew-ext-encode-switch))))
       ;;message-header
-      (cond 
+      (cond
        ((string= access-type "url")
 	(setq name "URL")
 	(setq ct "Text/Html"))
        ((string= access-type "mail-server")
 	(setq name "Mail server's file")
 	(setq ct mew-ct-apo))
-       (t 
+       (t
 	(setq name (file-name-nondirectory
 		    (mew-chop (mew-syntax-get-param ret "name"))))
 	;; name is quoted
@@ -182,9 +182,9 @@
 
 (defun mew-ext-encode-ftp ()
   ;; "name" "site" "directory" "mode"
-  (let ((mew-ext-host (mew-input-general 
+  (let ((mew-ext-host (mew-input-general
 		       "FTP server"
-		       (if mew-ext-ftp-server-list 
+		       (if mew-ext-ftp-server-list
 			   (mapcar 'list mew-ext-ftp-server-list))
 		       nil
 		       (car mew-ext-ftp-server-list)))
@@ -218,7 +218,7 @@
   (let ((mew-ext-user "anonymous")
 	(mew-ext-host (mew-input-general
 		       "FTP server"
-		       (if mew-ext-ftp-server-list 
+		       (if mew-ext-ftp-server-list
 			   (mapcar 'list mew-ext-ftp-server-list))
 		       nil
 		       (car mew-ext-ftp-server-list)))
@@ -255,7 +255,7 @@
 	  (list "subject" subject))))
 
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
-   
+
 (defun mew-ext-encode-url ()
   ;; "url"
   (let ((url (read-string "URL: ")))
@@ -285,7 +285,7 @@
 
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 
-(defun mew-ext-ftp (cache begin end &optional params)
+(defun mew-ext-ftp (_cache _begin _end &optional params)
   (mew-elet
    (let* ((site (mew-syntax-get-param params "site"))
 	  (directory (mew-syntax-get-param params "directory"))
@@ -314,7 +314,7 @@
       "To get this file, type "
       "'\\<mew-summary-mode-map>\\[mew-summary-execute-external]'.\n"))))
 
-(defun mew-ext-ftp-ext (cache begin end &optional params)
+(defun mew-ext-ftp-ext (_cache _begin _end &optional params)
   (let* ((site (mew-syntax-get-param params "site"))
 	 (directory (mew-syntax-get-param params "directory"))
 	 (name (mew-syntax-get-param params "name"))
@@ -337,12 +337,12 @@
 
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 
-(defun mew-ext-tftp (cache begin end &optional params)
+(defun mew-ext-tftp (_cache _begin _end &optional _params)
   (message "Access-type TFTP is not supported yet"))
 
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 
-(defun mew-ext-anon-ftp (cache begin end &optional params)
+(defun mew-ext-anon-ftp (_cache _begin _end &optional params)
   (mew-elet
    (let* ((site (mew-syntax-get-param params "site"))
 	  (directory (mew-syntax-get-param params "directory"))
@@ -372,20 +372,17 @@
       "To get this file, type "
       "'\\<mew-summary-mode-map>\\[mew-summary-execute-external]'.\n"))))
 
-(defun mew-ext-anon-ftp-ext (cache begin end &optional params)
+(defun mew-ext-anon-ftp-ext (_cache _begin _end &optional params)
   (let* ((site (mew-syntax-get-param params "site"))
 	 (directory (mew-syntax-get-param params "directory"))
 	 (name (mew-syntax-get-param params "name"))
 	 (getit t)
-	 filepath localfile lfname remotefile url)
+	 filepath localfile lfname remotefile)
     (if directory
 	(setq filepath (mew-concat-folder directory name))
       (setq filepath name))
     (setq filepath (mew-remove-drive-letter filepath))
     (setq remotefile (format "/%s@%s:%s" "anonymous" site filepath))
-    (if (string-match "^[/\:]" filepath)
-	(setq url (format "ftp://%s%s" site filepath))
-      (setq url (format "ftp://%s/%s" site filepath)))
     (setq localfile (mew-summary-input-file-name "Save to: " name))
     (setq lfname (file-name-nondirectory localfile))
     (if (file-exists-p localfile)
@@ -393,18 +390,11 @@
 	    (mew-delete-file localfile)
 	  (setq getit nil)
 	  (message "The file was not retrieved")))
-    (when getit
-      (cond
-       ((eq mew-ext-anon-ftp-method 'ftp)
-	(mew-ext-copy-file-internal
-	 remotefile localfile (mew-mail-address)))
-       ((eq mew-ext-anon-ftp-method 'http)
-	(require 'w3)
-	(w3-fetch url))))))
+    (if getit (mew-ext-copy-file-internal remotefile localfile (mew-mail-address)))))
 
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 
-(defun mew-ext-mail-server (cache begin end &optional params)
+(defun mew-ext-mail-server (_cache _begin _end &optional params)
   (mew-elet
    (let* ((server (mew-syntax-get-param params "server"))
 	  (size (mew-syntax-get-param params "size")))
@@ -438,8 +428,7 @@
 
 (defun mew-ext-decode-message-header (cache begin end)
   (let (syntax start)
-    (save-excursion
-      (set-buffer cache)
+    (with-current-buffer cache
       (save-restriction
 	(narrow-to-region begin end)
 	(goto-char (point-min))
@@ -459,8 +448,8 @@
 	  (process-connection-type mew-connection-type1)
 	  (syntax (mew-ext-decode-message-header cache begin end))
 	  (mct (car (mew-syntax-get-ct syntax)))
-	  (prog-list (mew-ext-url-by-ct mct))
-	  (doc (mew-ext-url-get-doc prog-list)))
+	  (spec mew-prog-text/html-ext)
+	  (prog (mew-progspec-get-prog spec)))
      (mew-erase-buffer)
      (insert "#     # ######  #\n"
 	     "#     # #     # #\n"
@@ -473,41 +462,19 @@
      (mew-insert "URL:\t\t%s\n" url)
      (mew-insert "Content-Type:\t%s\n" mct)
      (mew-insert "Size:\t%s bytes\n" size)
-     (mew-insert "Operation:\t%s\n" (or doc "not defined"))
+     (mew-insert "Operation:\t%s\n" (or prog "not defined"))
      (insert "\n")
      (mew-insert-manual
       "To operate this URL, type "
       "'\\<mew-summary-mode-map>\\[mew-summary-execute-external]'.\n"))))
 
-(defun mew-ext-url-ext (cache begin end &optional params)
+(defun mew-ext-url-ext (_cache _begin _end &optional params)
   (let* ((url (mew-syntax-get-param params "url"))
 	 (process-connection-type mew-connection-type1)
-	 (syntax (mew-ext-decode-message-header cache begin end))
-	 (mct (car (mew-syntax-get-ct syntax)))
-	 (prog-list (mew-ext-url-by-ct mct))
-	 (prog (mew-ext-url-get-prog prog-list))
-	 (args (mew-ext-url-get-args prog-list))
-	 pnm)
-    (cond
-     ((and (symbolp prog) (fboundp prog))
-      (message "Call function: (%s %s %s)" prog args url)
-      (funcall prog args url))
-     ((stringp prog)
-      (setq args (append args (list url)))
-      (message "Executing %s..."
-	       (mapconcat 'identity (append (list prog) args) " "))
-      (save-excursion ;; xxx this is necessary in other places
-	(setq pnm (format "*Mew %s*" prog))
-	(apply 'start-process pnm nil prog args)))
-     (t (message "Program list error")))))
-
-(defun mew-ext-url-show-by-w3 (dummy url)
-  (require 'w3)
-  (w3-fetch-other-frame url))
-
-(defun mew-ext-url-fetch-by-w3 (dummy url)
-  (require 'w3)
-  (w3-fetch url))
+	 (spec mew-prog-text/html-ext)
+	 (prog (mew-progspec-get-prog spec))
+	 (args (mew-progsec-args-convert (mew-progspec-get-args spec) url)))
+    (apply 'call-process prog nil nil nil args)))
 
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 
@@ -525,13 +492,13 @@
 
 ;;; Copyright Notice:
 
-;; Copyright (C) 1996-2007 Mew developing team.
+;; Copyright (C) 1996-2015 Mew developing team.
 ;; All rights reserved.
 
 ;; Redistribution and use in source and binary forms, with or without
 ;; modification, are permitted provided that the following conditions
 ;; are met:
-;; 
+;;
 ;; 1. Redistributions of source code must retain the above copyright
 ;;    notice, this list of conditions and the following disclaimer.
 ;; 2. Redistributions in binary form must reproduce the above copyright
@@ -540,7 +507,7 @@
 ;; 3. Neither the name of the team nor the names of its contributors
 ;;    may be used to endorse or promote products derived from this software
 ;;    without specific prior written permission.
-;; 
+;;
 ;; THIS SOFTWARE IS PROVIDED BY THE TEAM AND CONTRIBUTORS ``AS IS'' AND
 ;; ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 ;; IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
