@@ -27,9 +27,9 @@ A file name of a certificate should be 'cert-hash.0'.
 
 (defvar mew-prog-ssl-arg nil
   "For stunnel v3, a list of command-line arguments, each one a string.
-For stunnel v4, a string of extra text to place in the configuration file,
-which should end with a newline (example: \"fips=no\\n\"); or nil to insert
-no extra text.")
+For stunnel v4 or v5, a string of extra text to place in the configuration
+file, which should end with a newline (example: \"fips=no\\n\"); or nil to
+insert no extra text.")
 
 (defvar mew-ssl-ver nil)
 (defvar mew-ssl-minor-ver nil)
@@ -118,7 +118,7 @@ no extra text.")
 	(insert (format "[%d]\n" localport))
 	(insert (format "accept=%s:%d\n" mew-ssl-localhost localport))
 	(insert (format "connect=%s:%d\n" server remoteport))
-	(if tls (insert (format "protocol=%s\nsslVersion=TLSv1\n" tls)))
+	(if tls (insert (format "protocol=%s\n" tls)))
 	(mew-frwlet mew-cs-dummy mew-cs-text-for-write
 	  ;; NEVER use call-process-region for privacy reasons
 	  (write-region (point-min) (point-max) file nil 'no-msg))
@@ -155,7 +155,7 @@ A local port number can be obtained the process name after ':'. "
 	(message "Creating an SSL/TLS connection...")
 	(setq pro nil)
 	(catch 'loop
-	  (dotimes (i N)
+	  (dotimes (_i N) ;; prevent byte-compile warning
 	    (setq name (mew-ssl-info-name server remoteport localport))
 	    (setq opts (mew-ssl-options case server remoteport localport tls))
 	    (setq pro (apply 'start-process name nil mew-prog-ssl opts))
@@ -241,18 +241,18 @@ A local port number can be obtained the process name after ':'. "
       (mew-ssl-set-string pnm string)
       (setq string (concat prev-str string))
       (cond
-       ((string-match "Negotiated \\|opened with SSL" string)
+       ((string-match "Negotiated \\| ciphersuite:\\|opened with SSL" string)
 	(mew-ssl-set-status pnm t))
        ((string-match "Failed to initialize" string)
 	(mew-ssl-set-status pnm t)) ;; xxx
        ((string-match "verify failed" string)
 	(mew-ssl-set-status pnm 'verify-failure))))))
 
-(defun mew-ssl-filter3 (process string)
+(defun mew-ssl-filter3 (_process string)
   (save-excursion
     (mew-ssl-debug "SSL/TLS: " string)))
 
-(defun mew-ssl-sentinel (process event)
+(defun mew-ssl-sentinel (process _event)
   (let* ((pnm (process-name process))
 	 (file (mew-ssl-get-file pnm)))
     (save-excursion
