@@ -19,9 +19,6 @@
       (mew-elet
        (goto-char (point-max))
        (unless (bolp) (insert "\n"))
-       (if (and mew-xemacs-p (extent-at (point) nil nil nil 'at))
-	   ;; to skip graphics
-	   (insert "\n"))
        (mew-message-clear-end-of)
        (when (or mew-end-of-message-string mew-end-of-part-string)
 	 (move-overlay (mew-minfo-get-eom) (point-max) (point-max))
@@ -31,7 +28,7 @@
 	       (mew-message-set-end-of-part))
 	   (mew-message-set-end-of-message)))))))
 
-(defsubst mew-message-clear-end-of ()
+(defun mew-message-clear-end-of ()
   (unless (overlayp (mew-minfo-get-eom))
     (mew-minfo-set-eom (mew-overlay-make (point-max) (point-max))))
   (mew-message-set-end-of-nil))
@@ -98,8 +95,8 @@ If nodisplay is non-nil, displays the cached message."
 ;;; After step
 ;;;
 
-(defsubst mew-summary-display-after (direction)
-  (cond 
+(defun mew-summary-display-after (direction)
+  (cond
    ((eq direction 'down)
     (mew-summary-display-down))
    ((eq direction 'up)
@@ -116,20 +113,21 @@ If nodisplay is non-nil, displays the cached message."
 (defun mew-summary-recenter ()
   "Make the current line to the center of Summary mode."
   (interactive)
-  (if (or mew-summary-recenter-p (interactive-p))
+  (if (or mew-summary-recenter-p (mew-called-interactively-p))
       (recenter (/ (- (window-height) 2) 2))))
 
-(defsubst mew-summary-display-preamble ()
+(defun mew-summary-display-preamble ()
   ;; message buffer
   (mew-erase-buffer)
   (mew-message-clear-end-of)
   (mew-overlay-delete-buffer) ;; veil, xxx also delete extents?
   ;; kill mark for cite
-  (and (mark-marker) (set-marker (mark-marker) nil)))
+  (and (mark-marker) (set-marker (mark-marker) nil))
+  (mew-normal-line))
 
 (defvar mew-message-last-buffer nil)
 
-(defsubst mew-summary-display-postscript (&optional no-hook)
+(defun mew-summary-display-postscript (&optional no-hook)
   ;; message buffer
   (unless no-hook (run-hooks 'mew-message-hook))
   (mew-minfo-set-reob nil)
@@ -144,6 +142,7 @@ If nodisplay is non-nil, displays the cached message."
   (mew-highlight-cursor-line)
   (when (and mew-use-unread-mark
 	     (mew-summary-message-number)
+	     ;; mark would be nil. MUST be equal
 	     (equal (mew-summary-get-mark) mew-mark-unread))
     (unless (and mew-inherit-after-marking
 		 (not mew-delete-unread-mark-by-mark))
@@ -155,7 +154,7 @@ If nodisplay is non-nil, displays the cached message."
 ;;; Displaying
 ;;;
 
-(defsubst mew-summary-message-toobig (fld msg)
+(defun mew-summary-message-toobig (fld msg)
   (let ((file (mew-expand-msg fld msg)))
     (and (file-readable-p file)
 	 (> (mew-file-get-size file) mew-file-max-size))))
@@ -184,7 +183,7 @@ function displays the current message or part. Even if it is
 already displayed, this function displays it again getting back
 to the beginning."
   (interactive "P")
-  (when (or redisplay (mew-sinfo-get-disp-msg) (interactive-p))
+  (when (or redisplay (mew-sinfo-get-disp-msg) (mew-called-interactively-p))
     (mew-summary-msg-or-part
      (let* ((fld (mew-summary-folder-name))
 	    (vfld (mew-summary-folder-name 'ext))
@@ -196,7 +195,7 @@ to the beginning."
 	    (opart (mew-current-get-part fid))
 	    (cache (mew-cache-hit fld (or msg omsg)))
 	    (win (selected-window))
-	    (read-through (interactive-p))
+	    (read-through (mew-called-interactively-p))
 	    (sumbuf (current-buffer))
 	    next prefetch)
        (unwind-protect
@@ -348,7 +347,7 @@ This function does not create a cache."
 ;;;
 
 (defun mew-summary-analyze-again-alternative (&optional arg)
-  "This command analyzes the message again with 
+  "This command analyzes the message again with
 'mew-use-alternative' and 'mew-use-text-body' reversed."
   (interactive "P")
   (mew-summary-goto-message)
@@ -433,7 +432,7 @@ displays it."
   "Insert this message or part into Message mode in the raw format.
 This command treats PGP/MIME transparent. That is an encrypted/signed
 part is displayed as a decrypted/verified part. Also, if this command
-is used for a message whose entire body is encrypted/signed, 
+is used for a message whose entire body is encrypted/signed,
 a decrypted/verified body is displayed."
   (interactive)
   (mew-summary-msg-or-part
@@ -448,8 +447,7 @@ a decrypted/verified body is displayed."
 		   (mew-cache-dinfo-get-use-alt cbuf)
 		 mew-use-alternative))
 	  syntax ct begin end)
-     (save-excursion
-       (set-buffer buf)
+     (with-current-buffer buf
        (mew-erase-buffer)
        (mew-insert-message fld msg mew-cs-text-for-read nil)
        (mew-dinfo-set nil t nil alt)
@@ -465,7 +463,7 @@ a decrypted/verified body is displayed."
 	   ;; message buffer
 	   (mew-current-set fld msg nums)
 	   (mew-minfo-set-summary vfld)
-	   ;; The following codes are not necessary. 
+	   ;; The following codes are not necessary.
 	   ;; (mew-decode-syntax-clear)
 	   ;; (mew-decode-syntax-delete)
 	   (mew-elet
@@ -505,11 +503,10 @@ If called with '\\[universal-argument]', it stays writable."
 	  (file (mew-expand-msg fld msg)))
      (when (mew-sinfo-get-disp-msg)
        (mew-summary-toggle-disp-msg))
-     (mew-frwlet
-      (if (mew-folder-draftp fld) mew-cs-m17n mew-cs-autoconv) mew-cs-dummy
-      (if arg
-	  (switch-to-buffer (mew-find-file-noselect2 file))
-	(view-buffer (mew-find-file-noselect2 file) 'kill-buffer))))))
+     (mew-frwlet (if (mew-folder-draftp fld) mew-cs-m17n mew-cs-autoconv) mew-cs-dummy
+       (if arg
+	   (switch-to-buffer (mew-find-file-noselect2 file))
+	 (view-buffer (mew-find-file-noselect2 file) 'kill-buffer))))))
 
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 ;;;
@@ -523,7 +520,7 @@ If called with '\\[universal-argument]', it stays writable."
    (let* ((win (selected-window))
 	  (fld (mew-summary-folder-name))
 	  (msg (mew-summary-message-number2))
-	  lst ent svr-date snd rcv svr date tmp)
+	  lst svr-date (snd "?") (rcv "?") last svr date tmp)
      (mew-summary-set-message-buffer fld msg)
      ;; message buffer or cache buffer
      (setq lst (nreverse (mew-header-get-value mew-received: 'as-list)))
@@ -531,9 +528,9 @@ If called with '\\[universal-argument]', it stays writable."
      ;; message buffer
      (mew-summary-display-preamble)
      (save-excursion
-       (while lst
-	 (setq ent (car lst))
-	 (setq lst (cdr lst))
+       (dolist (ent lst)
+	 (while (string-match "\n" ent)
+	   (setq ent (replace-match "" nil t ent)))
 	 (setq svr-date (mew-split ent ?\;))
 	 (mew-set '(svr date) svr-date)
 	 (unless date
@@ -546,10 +543,12 @@ If called with '\\[universal-argument]', it stays writable."
 	 (cond
 	  ((string-match "(\\(qmail [0-9]+\\)" svr)
 	   (setq rcv (match-string 1 svr)))
-	  ((string-match "by[ \t]*\\([^() \t\n]+\\)" svr)
+	  ((string-match "by[ \t]+\\([^() \t\n]+\\)" svr)
 	   (setq rcv (match-string 1 svr))
-	   (if (string-match "from[ \t]*\\([^() \t\n]+\\).*\\(\\[[.0-9]+\\]\\)" svr)
-	       (setq snd (format "%s %s" (match-string 1 svr) (match-string 2 svr))))
+	   (if (string-match "from[ \t]+\\([^() \t\n]+\\).*\\([[][.0-9]+[]]\\)" svr)
+	       (setq snd (format "%s %s" (match-string 1 svr) (match-string 2 svr)))
+	     (if (string-match "from[ \t]+\\([^() \t\n]+\\)" svr)
+		 (setq snd (match-string 1 svr))))
 	   (when (and (string= snd "unknown")
 		      (string-match "from unknown (HELO \\([^() \t\n]+\\))" svr))
 	     (setq snd (concat (match-string 1 svr) "(unknown)"))))
@@ -572,11 +571,12 @@ If called with '\\[universal-argument]', it stays writable."
 	  (insert ":")
 	  (forward-char 2)
 	  (insert " (" (mew-time-tmzn-int) ") ")
-	  (if snd (insert snd))
+	  (if (and snd (not (string= snd last))) (insert snd))
 	  (insert " => ")
 	  (if rcv (insert rcv))
 	  (insert "\n")
-	  (setq snd nil rcv nil))))
+	  (setq last rcv)
+	  (setq snd "?" rcv "?"))))
      (mew-summary-display-postscript 'no-hook)
      (select-window win))))
 
@@ -608,14 +608,14 @@ ad-hoc solution for putting the review mark on a thread.")
 
 (defun mew-summary-down ()
   (funcall mew-summary-down-function)
-  (cond 
+  (cond
    ((mew-re-search-forward-visibile mew-regex-msg-or-part)
     (mew-thread-move-cursor)
     (mew-sinfo-set-direction 'down)
     t)
    (t
     (mew-decode-syntax-delete)
-    (previous-line 1) ;; for invisible
+    (forward-line -1) ;; for invisible
     (unless (pos-visible-in-window-p)
       ;; This ensures that some messages are displayed in Summary.
       (recenter))
@@ -626,12 +626,12 @@ ad-hoc solution for putting the review mark on a thread.")
 
 (defun mew-summary-up ()
   (beginning-of-line)
-  (cond 
+  (cond
    ((mew-re-search-backward-visible mew-regex-msg-or-part)
     (mew-thread-move-cursor)
     (mew-sinfo-set-direction 'up)
     t)
-   (t 
+   (t
     (mew-thread-move-cursor)
     (mew-decode-syntax-delete)
     (mew-summary-reset)
@@ -647,7 +647,7 @@ ad-hoc solution for putting the review mark on a thread.")
   (if (mew-summary-next) (mew-summary-display)))
 
 (defun mew-summary-display-up (&optional arg)
-  "Move to above then display. Targets includes parts, messages 
+  "Move to above then display. Targets includes parts, messages
 marked with '*', and non-marked messages. When called with '\\[universal-argument]',
 parts are skipped."
   (interactive "P")
@@ -658,7 +658,7 @@ parts are skipped."
   (if (mew-summary-up) (mew-summary-display)))
 
 (defun mew-summary-display-down (&optional arg)
-  "Move to below then display. Targets includes parts, messages 
+  "Move to below then display. Targets includes parts, messages
 marked with '*', and non-marked messages. When called with '\\[universal-argument]',
 parts are skipped."
   (interactive "P")
@@ -738,8 +738,8 @@ over the window. Type '\\[mew-summary-prev-page]' to see them when a message is
   (or arg (setq arg 1))
   (if (< arg 0)
       (mew-summary-previous-line (- arg))
-    (let (col) 
-      (if (eq last-command this-command) 
+    (let (col)
+      (if (eq last-command this-command)
 	  (setq col (mew-sinfo-get-column)))
       (unless col
 	(setq col (current-column))
@@ -758,15 +758,16 @@ over the window. Type '\\[mew-summary-prev-page]' to see them when a message is
   (or arg (setq arg 1))
   (if (< arg 0)
       (mew-summary-next-line (- arg))
-    (let (col) 
-      (if (eq last-command this-command) 
+    (let (col)
+      (if (eq last-command this-command)
 	  (setq col (mew-sinfo-get-column)))
       (unless col
 	(setq col (current-column))
 	(mew-sinfo-set-column col))
       (while (> arg 0)
-	(previous-line 1) ;; for invisible
-	(while (looking-at mew-regex-thread-separator)
+	(forward-line -1) ;; for invisible
+	(while (or (looking-at mew-regex-thread-separator)
+		   (eq (get-text-property (point) 'invisible) t))
 	  (forward-line -1))
 	(setq arg (1- arg)))
       (move-to-column col))))
@@ -787,13 +788,13 @@ over the window. Type '\\[mew-summary-prev-page]' to see them when a message is
 
 ;;; Copyright Notice:
 
-;; Copyright (C) 1996-2007 Mew developing team.
+;; Copyright (C) 1996-2015 Mew developing team.
 ;; All rights reserved.
 
 ;; Redistribution and use in source and binary forms, with or without
 ;; modification, are permitted provided that the following conditions
 ;; are met:
-;; 
+;;
 ;; 1. Redistributions of source code must retain the above copyright
 ;;    notice, this list of conditions and the following disclaimer.
 ;; 2. Redistributions in binary form must reproduce the above copyright
@@ -802,7 +803,7 @@ over the window. Type '\\[mew-summary-prev-page]' to see them when a message is
 ;; 3. Neither the name of the team nor the names of its contributors
 ;;    may be used to endorse or promote products derived from this software
 ;;    without specific prior written permission.
-;; 
+;;
 ;; THIS SOFTWARE IS PROVIDED BY THE TEAM AND CONTRIBUTORS ``AS IS'' AND
 ;; ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 ;; IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
